
# Generate Lesson Plan





## Tasks

### Design Process

    * Clarify the lesson purpose and identify the learning goal/intention for the lesson:
        * What do you want the students to learn?
        * Why does this learning matter?
    * Consider assessment:
        * How will you know the learning goal has been achieved?
    * Structure the lesson as a series of episodes:
        * How will the lesson flow to ensure the learning/goal intention is achieved?
    * Decide what will occur within each episode:
    * Which learning experiences and resources best support the achievement of the learning goal/intention?

### Generate Lesson Plans

    * Define detailed lesson plans for week 1 based on the information provided above, considering the following:
        * The scope of the lessons are provided above under Lesson Plans Summary.
        * Number of lessons is 3.
        * Duration of each lesson is 60 minutes.

### Expected output

    * Format the response in markdown
    * Here's a list of the detailed lesson plan template to use:
        * Unit Title - Year Level - Week
        * Content Descriptions
        * Lesson Title
        * Lesson Objective
        * Lesson Outcomes
        * Ask the curriculum_expert to generate detailed lesson plans based on the Lesson Plans Summary, then format the the response as:
            * Lesson Structure (Breakdown lesson activities to time slots in a table. For each slot generate):
                * Time
                * Content (Teaching Points - full details of what will be taught in the lesson including examples)
                * Teacher Script (include a teacher script - exact steps - for the teacher to follow)
                * Teaching Approach
                * Resources/Materials
        * Assessments
